module.exports = {
  root: true,
  env: {
    browser: true,
    node: true
  },
  parserOptions: {
    parser: "babel-eslint"
  },
  extends: [
    "plugin:prettier/recommended",
    "plugin:vue/recommended",
    "plugin:nuxt/recommended",
    "eslint:recommended",
    "plugin:import/errors",
    "plugin:import/warnings"
  ],
  plugins: ["vue"],
  rules: {
    "array-bracket-spacing": ["error", "never"],
    "arrow-parens": "off",
    "arrow-spacing": ["error", {
      "after": true,
      "before": true
    }],
    "block-spacing": ["error", "always"],
    "brace-style": ["error", "1tbs"],
    "camelcase": ["error"],
    "camelcase": "off",
    "consistent-this": "warn",
    "capitalized-comments": ["error", "always"],
    "consistent-return": "off",
    "consistent-this": "warn",
    // Force curly braces for control flow,
    // including if blocks with a single statement
    "curly": ["error", "all"],
    // Force dot notation when possible
    "dot-notation": "error",
    "eol-last": ["error", "always"],
    "func-call-spacing": ["error", "never"],
    "function-call-argument-newline": ["error", "consistent"],
    "function-paren-newline": "off",
    // Allow async-await
    "generator-star-spacing": "off",
    "handle-callback-err": "off",
    "implicit-arrow-linebreak": "off",
    // Imports should come first
    "import/first": "error",
    // Other import rules
    "import/no-mutable-exports": "error",
    // Allow unresolved imports
    "import/no-unresolved": "off",
    // Enforce import order
    "import/order": "error",
    "indent": "off",
    "init-declarations": "off",
    "key-spacing": ["error", {
      "afterColon": true,
      "beforeColon": false
    }],
    "linebreak-style": ["error", "unix"],
    "new-parens": ["error", "always"],
    "no-alert": ["off"],
    "no-case-declarations": "off",
    "no-console": process.env.NODE_ENV === "production" ? "error" : "warn",
    // Allow debugger during development
    "no-debugger": process.env.NODE_ENV === "production" ? "error" : "warn",
    "no-empty-function": "off",
    "no-eval": "off",
    "no-extend-native": "off",
    "no-label-var": ["error"],
    // No single if in an "else" block
    "no-lonely-if": "error",
    "no-multi-assign": ["error"],
    "no-multiple-empty-lines": ["error", {
      max: 2
    }],
    "no-new": "off",
    "no-new-require": ["error"],
    "no-path-concat": "off",
    "no-trailing-spaces": ["error"],
    "no-undef": "off",
    "no-unused-vars": "warn",
    // No useless destructuring/importing/exporting renames
    "no-useless-rename": "error",
    "no-var": "error",
    "object-curly-spacing": ["error", "always"],
    // Force object shorthand where possible
    "object-shorthand": "error",
    "one-var": ["error", "never"],
    "one-var-declaration-per-line": ["error", "always"],
    "operator-linebreak": "off",
    "padded-blocks": ["error", "never"],
    // Prefer const over let
    "prefer-const": ["error", {
      "destructuring": "any",
      "ignoreReadBeforeAssign": false
    }],
    "prefer-promise-reject-errors": "off",
    // No async function without await
    "require-await": "error",
    "semi-spacing": ["error", {
      "after": true,
      "before": false
    }],
    "space-before-blocks": ["error", "always"],
    "space-before-function-paren": ["error", {
      "anonymous": "always",
      "asyncArrow": "always",
      "named": "never"
    }],
    "standard/no-callback-literal": "off",
    "valid-typeof": "off"
  },
  settings: {
    "import/resolver": {
      node: { extensions: [".js", ".mjs"] }
    }
  }
};
